@@ -103,6 +103,8 @@ class ProvisionProductTask(PuppetTask):
 
     ssm_param_outputs = luigi.ListParameter(default=[])
 
+    should_use_sns = luigi.Parameter(significant=False, default=False)
+
     try_count = 1
 
     def requires(self):
@@ -163,7 +165,7 @@ class ProvisionProductTask(PuppetTask):
                 'servicecatalog', role, f'sc-{self.region}-{self.account_id}', region_name=self.region
         ) as service_catalog:
             logger.info(f"[{self.launch_name}] {self.account_id}:{self.region} :: looking for previous failures")
-            path_id = aws.get_path_for_product(service_catalog, self.product_id)
+            path_id = aws.get_path_for_product(service_catalog, self.product_id, self.portfolio)
 
             provisioned_product_id, provisioning_artifact_id = aws.terminate_if_status_is_not_available(
                 service_catalog, self.launch_name, self.product_id, self.account_id, self.region
@@ -249,6 +251,7 @@ class ProvisionProductTask(PuppetTask):
                         path_id,
                         all_params,
                         self.version,
+                        self.should_use_sns,
                     )
 
                 with betterboto_client.CrossAccountClientContextManager(
@@ -723,6 +726,8 @@ class CreateAssociationsForPortfolioTask(PuppetTask):
     associations = luigi.ListParameter(default=[])
     dependencies = luigi.ListParameter(default=[])
 
+    should_use_sns = luigi.Parameter(significant=False, default=False)
+
     def requires(self):
         return {
             'create_spoke_local_portfolio_task': CreateSpokeLocalPortfolioTask(
@@ -769,7 +774,7 @@ class CreateAssociationsForPortfolioTask(PuppetTask):
                 TemplateBody=template,
                 NotificationARNs=[
                     f"arn:aws:sns:{self.region}:{self.puppet_account_id}:servicecatalog-puppet-cloudformation-regional-events"
-                ],
+                ] if self.should_use_sns else [],
             )
             result = cloudformation.describe_stacks(
                 StackName=stack_name,
@@ -993,6 +998,8 @@ class CreateLaunchRoleConstraintsForPortfolio(PuppetTask):
 
     dependencies = luigi.ListParameter(default=[])
 
+    should_use_sns = luigi.Parameter(default=False, significant=False)
+
     def requires(self):
         return {
             'create_spoke_local_portfolio_task': ImportIntoSpokeLocalPortfolioTask(
@@ -1050,16 +1057,20 @@ class CreateLaunchRoleConstraintsForPortfolio(PuppetTask):
                 product_name_to_id_dict=product_name_to_id_dict,
             )
             time.sleep(30)
-            stack_name = f"launch-constraints-for-portfolio-{portfolio_id}"
+            stack_name_v1 = f"launch-constraints-for-portfolio-{portfolio_id}"
+            cloudformation.ensure_deleted(
+                StackName=stack_name_v1,
+            )
+            stack_name_v2 = f"launch-constraints-v2-for-portfolio-{portfolio_id}"
             cloudformation.create_or_update(
-                StackName=stack_name,
+                StackName=stack_name_v2,
                 TemplateBody=template,
                 NotificationARNs=[
                     f"arn:aws:sns:{self.region}:{self.puppet_account_id}:servicecatalog-puppet-cloudformation-regional-events"
-                ],
+                ] if self.should_use_sns else [],
             )
             result = cloudformation.describe_stacks(
-                StackName=stack_name,
+                StackName=stack_name_v2,
             ).get('Stacks')[0]
             f = self.output().open('w')
             f.write(
